## NEXT

## v0.4.0

- Replace local `operators` module with equivalent module from `numerical` package
- Redefine equality to always return a single boolean value

## v0.3.0

- Incorporate `numerical` package
- Add `typeface` module

## v0.2.0

- Rename `_types` submodule to `abstract`

## v0.1.0

- Hello world!
